"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ = require("./..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/** @component radio */
var Radio = function Radio(props) {
  var disabled = props.disabled,
      required = props.required,
      checked = props.checked,
      name = props.name,
      label = props.label,
      value = props.value,
      inputRef = props.inputRef,
      htmlId = props.htmlId,
      onChange = props.onChange,
      children = props.children,
      className = props.className,
      nestedLevel = props.nestedLevel;
  return _react.default.createElement("div", {
    className: 'cui-input-group cui-radio' + ("" + (nestedLevel && " cui-input--nested-" + nestedLevel || '')) + (" " + className)
  }, _react.default.createElement("input", {
    className: 'cui-input cui-radio__input',
    type: "radio",
    ref: inputRef,
    disabled: disabled,
    checked: checked,
    required: required,
    name: name,
    value: value,
    id: htmlId,
    onChange: onChange,
    tabIndex: 0
  }), _react.default.createElement(_.Label, {
    className: "cui-radio__label",
    label: label,
    htmlFor: htmlId
  }), children);
};

Radio.propTypes = {
  /** @prop Boolean for whether the Radio button is checked | false */
  checked: _propTypes.default.bool,

  /** @prop Children nodes to render insdie Radio component | null */
  children: _propTypes.default.node,

  /** @prop Optional CSS class name | '' */
  className: _propTypes.default.string,

  /** @prop Sets the attribute disabled to the Radio | false */
  disabled: _propTypes.default.bool,

  /** @prop Unique HTML ID used for tying label to HTML input for automated testing */
  htmlId: _propTypes.default.string.isRequired,

  /** @prop Optional ref attribute for Radio input element | null */
  inputRef: _propTypes.default.func,

  /** @prop Radio label text | '' */
  label: _propTypes.default.string,

  /** @prop Radio name string | '' */
  name: _propTypes.default.string,

  /** @prop Set the level of nested Radios | 0 */
  nestedLevel: _propTypes.default.number,

  /** @prop Callback function invoked when user makes a change with the Radio button | null */
  onChange: _propTypes.default.func,

  /** @prop Requires the user to populate the Radio input | false */
  required: _propTypes.default.bool,

  /** @prop String value that corresponds with Radio button | '' */
  value: _propTypes.default.string
};
Radio.defaultProps = {
  checked: false,
  children: null,
  className: '',
  disabled: false,
  inputRef: null,
  label: '',
  name: '',
  nestedLevel: 0,
  onChange: function onChange() {},
  required: false,
  value: ''
};
Radio.displayName = 'Radio';
var _default = Radio;
exports.default = _default;